@@ -8,6 +8,7 @@ from itertools import izip
 
 from .functions        import parse_indices
 from .coordinatebounds import CoordinateBounds
+from .timeduration     import TimeDuration
 from .variable         import Variable, SubspaceVariable
 
 from .data.data import Data
@@ -1333,13 +1334,11 @@ Join a sequence of coordinates together.
         if len(coordinates) == 1:
             return coordinates0.copy()
 
-        out = Variable.concatenate(coordinates, axis=axis,
-                                   _preserve=_preserve)
-        
+        out = Variable.concatenate(coordinates, axis=axis, _preserve=_preserve)
+
         if coord0._hasbounds:
             bounds = Variable.concatenate(
-                [c.bounds for c in coordinates],
-                axis=axis, _preserve=_preserve)
+                [c.bounds for c in coordinates], axis=axis, _preserve=_preserve)
 
             out.insert_bounds(bounds, copy=False)
         
@@ -2786,13 +2785,20 @@ create bounds based on the coordinate array values.
         size = array.size    
 
         if cellsize is not None:
+#            if not isinstance(cellsize, TimeDuration):
             cellsize = Data.asdata(abs(cellsize))
             if cellsize.Units:
                 if not cellsize.Units.equivalent(self.Units):
                     raise ValueError("jhgsjhbd jh ")
                 cellsize.Units = self.Units
             cellsize = cellsize.datum()
+        #--- End: def
 
+#        if isinstance(cellsize, TimeDuration):
+#            pass
+#            bounds = numpy_empty((size, 2), dtype=dtype)
+#            cellsize = None
+     
         if bound is None:
             # Creat Voronoi bounds
             if size < 2:
@@ -2813,7 +2819,7 @@ create bounds based on the coordinate array values.
 
             dtype = type(bounds_1d[0])
 
-        else:
+        else:      
             direction = self.direction()
             if not direction and size > 1:
                 array = array[::-1]
