@@ -576,7 +576,7 @@ cell_methods)
                 coord = seen_in_file[ncdim].copy()
             else:
                 coord = _create_Coordinate(nc, ncdim, attributes, f, cfa=cfa,
-                                           dimension=True)
+                                           dimension=True, verbose=verbose)
                 seen_in_file[ncdim] = coord                
             #--- End: if
 
@@ -627,7 +627,7 @@ cell_methods)
                 coord = seen_in_file[ncvar].copy()
             else:
                 coord = _create_Coordinate(nc, ncvar, attributes, f, cfa=cfa,
-                                           dimension=False)
+                                           dimension=False, verbose=verbose)
                 seen_in_file[ncvar] = coord
             #--- End: if
 
@@ -747,7 +747,7 @@ cell_methods)
 #--- End: def
 
 def _create_Coordinate(nc, ncvar, attributes, f, cfa=False,
-                       dimension=True):
+                       dimension=True, verbose=False):
     '''
 
 Create a coordinate variable, including any bounds.
