@@ -252,13 +252,13 @@ and auxiliary coordinate roles for different data variables.
          'ncpdim_to_size'   : {},      # - Dictionary of PARTITION
                                        #   dimension sizes keyed by
                                        #   netCDF dimension names.
-         'seen'             : {},      # - Dictionary netCDF variable
-                                       #   names and netCDF
-                                       #   dimensions keyed by
-                                       #   elements of the field
-                                       #   (such as a coordinate or a
-                                       #   coordinate reference).
-                                       #-----------------------------
+         'seen'             : {},      # - Dictionary of netCDF
+                                       #   variable names and netCDF
+                                       #   dimensions keyed by items
+                                       #   of the field (such as a
+                                       #   coordinate or a coordinate
+                                       #   reference).
+                                       # -----------------------------
          'ncvar_names'      : set(()), # - Set of all netCDF
                                        #   dimension and netCDF
                                        #   variable names.
@@ -1017,12 +1017,9 @@ def _variable_ncvar(variable, default, counter, g=None):
 #--- End: def
     
 def _write_dimension(ncdim, f, axis, axis_to_ncdim, is_unlimited=False, g=None):
-    '''
+    '''Write a dimension to the netCDF file.
 
-Write a dimension to the netCDF file.
-
-.. note:: This function updates ``axis_to_ncdim``,
-          ``g['ncdim_to_size']``.
+.. note:: This function updates ``axis_to_ncdim``, ``g['ncdim_to_size']``.
 
 :Parameters:
 
@@ -1046,7 +1043,7 @@ Write a dimension to the netCDF file.
 
      None
 
-'''          
+    '''          
     size = f.axis_size(axis)
 
     g['ncdim_to_size'][ncdim] = size
@@ -1766,13 +1763,11 @@ created. The ``seen`` dictionary is updated for *cfvar*.
 
                     if numpy_intersect1d(missing_data, temp_array):
                         raise ValueError(
-"ERROR: Can't write field when array has _FillValue or missing_value at unmasked point: %r" %
-cfvar)
-                #--- End: if
-
+"ERROR: Can't write field when array has _FillValue or missing_value at unmasked point: {0!r}".format(
+    cfvar))
 
                 # Copy the array into the netCDF variable
-                g['nc'][ncvar][partition.indices] = array        
+                g['nc'][ncvar][partition.indices] = array
 
                 partition.close()
             #--- End: for                  
