@@ -1,13 +1,11 @@
-from struct import unpack as struct_unpack
-
 from glob import glob
-from os   import SEEK_SET
-
+from os      import walk as os_walk
+from os.path import isdir, isfile
+from os.path import join as os_path_join
 from os.path import expandvars as os_path_expandvars
 from os.path import expanduser as os_path_expanduser
 
 from .field     import Field, FieldList
-#from .fieldlist import FieldList
 from .functions import flat
 from .aggregate import aggregate as cf_aggregate
 
@@ -19,13 +17,15 @@ from .um.read     import is_um_file
 def read(files, verbose=False, ignore_read_error=False,
          aggregate=True, umversion=4.5, nfields=None, squeeze=False,
          unsqueeze=False, fmt=None, select=None, select_options={},
-         top_level=None, height_at_top_of_model=None):
+         top_level=None, height_at_top_of_model=None, recursive=False,
+         follow_symlinks=False):
     '''Read fields from files into `cf.Field` objects.
 
 A file may be on disk or on a OPeNDAP server.
 
-Any amount of any combination of CF-netCDF, CFA-netCDF and Met Office
-(UK) PP format files may be read.
+Any amount of any combination of CF-netCDF and CFA-netCDF files (or
+URLs if DAP access is enabled), Met Office (UK) PP files and Met
+Office (UK) fields files format files may be read.
 
 **netCDF files**
    * The netCDF variable names of the field and its components are
@@ -160,6 +160,25 @@ Any amount of any combination of CF-netCDF, CFA-netCDF and Met Office
 
         .. versionadded:: 1.0.4
 
+    recursive : bool, optional
+        If True then allow directories to be specified by the *files*
+        parameter and recursively search the directories for files to
+        read.
+
+        .. versionadded:: 1.1.9
+
+    follow_symlinks : bool, optional
+        If True, and *recursive* is True, then also search for files
+        in directories which resolve to symbolic links. By default
+        directories which resolve to symbolic links are
+        ignored. Ignored of *recursive* is False. Files which are
+        symbolic links are always followed.
+
+        Note that setting ``recursive=True, follow_symlinks=True`` can
+        lead to infinite recursion if a symbolic link points to a
+        parent directory of itself.
+
+        .. versionadded:: 1.1.9
 :Returns:
     
     out : cf.FieldList or cf.Field
@@ -199,7 +218,12 @@ Any amount of any combination of CF-netCDF, CFA-netCDF and Met Office
 
     '''
     if squeeze and unsqueeze:
-        raise ValueError("Can't squeeze and unsqueeze whilst reading")
+        raise ValueError("squeeze and unsqueeze can not both be True")
+
+    if follow_symlinks and not recursive:
+        raise ValueError(
+            "Can't set follow_symlinks={0} when recursive={1}".format(
+                follow_symlinks, recursive))
 
     # Initialize the output list of fields
     field_list = FieldList()
@@ -245,12 +269,28 @@ Any amount of any combination of CF-netCDF, CFA-netCDF and Met Office
         else:
             # Glob files on disk
             files2 = glob(file_glob)
+
             if not files2 and not ignore_read_error:
                 open(file_glob, 'rb')
+                
+            if recursive:
+                files3 = []
+                for x in files2:
+                    if isdir(x):
+                        # Recursively walk through directories
+                        for path, subdirs, filenames in os_walk(x, followlinks=follow_symlinks):
+                            files3.extend(os_path_join(path, f) for f in filenames)
+                    else:
+                        files3.append(x)
+                files2 = files3
+            else:
+                for x in files2:
+                    if isdir(x) and not ignore_read_error:
+                        raise IOError(
+"Can't read directory {0} recursively unless recursive=True".format(x))
         #--- End: if
 
         for filename in files2:
-            # Print some informative messages
             if verbose:
                 print 'File: %s' % filename
 
@@ -295,8 +335,8 @@ Any amount of any combination of CF-netCDF, CFA-netCDF and Met Office
     # Print some informative messages
     if verbose:
         print("Read {0} field{1} from {2} file{3}".format( 
-              (field_counter, _plural(field_counter),
-               file_counter , _plural(file_counter))))
+            field_counter, _plural(field_counter),
+            file_counter , _plural(file_counter)))
     #--- End: if
     
     # ----------------------------------------------------------------
@@ -311,8 +351,8 @@ Any amount of any combination of CF-netCDF, CFA-netCDF and Met Office
         if verbose:
             n = len(field_list)
             print('{0} input field{1} aggregated into {2} field{3}'.format(
-                  (org_len, _plural(org_len), 
-                   n, _plural(n))))
+                org_len, _plural(org_len), 
+                n, _plural(n)))
     #--- End: if
 
     # ----------------------------------------------------------------
